<?php

include 'vendor/autoload.php';

use GatewayWorker\BusinessWorker;
use GatewayWorker\Gateway;
use GatewayWorker\Lib\Gateway as LibGateway;
use GatewayWorker\Register;
use Workerman\Worker;
use Workerman\Timer;
use Workerman\MySQL\Connection;

class workerman
{
    public function startBusinessWorker()
    {
        global $config;
        $worker                  = new BusinessWorker();
        $worker->name            = 'BusinessWorker';
        $worker->count           = $config->board->worker->count;
        $worker->registerAddress = $config->board->worker->registerAddress;
        $worker->eventHandler    = workermanEvents::class;
    }

    public function startGateWay()
    {
        global $config;
        // $context = array(

        //      'ssl' => array(
        //          // 请使用绝对路径
        //             'local_cert'                 => '/etc/nginx/cert/zentaopms.com.pem',
        //             'local_pk'                   => '/etc/nginx/cert/zentaopms.com.key',
        //             'verify_peer'                => false,
        //             // 'allow_self_signed' => true, //如果是自签名证书需要开启此选项
        //         )
        //     );
        //$gateway = new Gateway($config->board->gateway->socketName, $context);
        $gateway = new Gateway($config->board->gateway->socketName);
        // $gateway->transport            = 'ssl';
        $gateway->name                 = 'Gateway';
        $gateway->count                = $config->board->gateway->count;
        $gateway->lanIp                = $config->board->gateway->lanIp;
        $gateway->startPort            = $config->board->gateway->startPort;
        $gateway->pingInterval         = $config->board->gateway->pingInterval;
        $gateway->pingNotResponseLimit = $config->board->gateway->pingNotResponseLimit;
        $gateway->pingData             = $config->board->gateway->pingData;
        $gateway->registerAddress      = $config->board->gateway->registerAddress;
    }

    public function startRegister()
    {
        global $config;
        new Register($config->board->register->socketName);
    }

    public function start()
    {
        $this->startRegister();
        $this->startGateWay();
        $this->startBusinessWorker();

        Worker::runAll();
    }
}

class workermanEvents
{
    public static function onWorkerStart($businessWorker)
    {
        echo "onWorkerStart\r\n";
        if($businessWorker->id === 0)
        {
            global $config, $app;
            $timeInterval   = $config->board->updateTimeInterval;
            $boardModelFile = $app->setModelFile('board');
            helper::import($boardModelFile);
            $boardModel = new boardModel();

            Timer::add($timeInterval, function() use ($boardModel)
            {
                $groups = LibGateway::getAllGroupIdList();
                foreach($groups as $canvasID)
                {
                    $updated = array();
                    $boardModel->processLayers((int) $canvasID, $updated);
                    if(!empty($updated))
                    {
                        LibGateway::sendToGroup($canvasID, json_encode(array('type' => 'option', 'canvas_id' => $canvasID, 'option_id' => 0, 'data' => $updated, 'server_resp' => true)));
                    }
                }
            });
        }

        global $config, $db;
        $db = new Connection($config->db->host, $config->db->port, $config->db->user, $config->db->password, $config->db->name);
    }

    public static function onConnect($clientId)
    {
        LibGateway::sendToClient($clientId, json_encode(['type' => 'onConnect', 'client_id' => $clientId]));
        echo "onConnect 「{$clientId}」\r\n";
    }

    public static function onWebSocketConnect($clientId, $data)
    {
        echo "onWebSocketConnect\r\n";
    }

    public static function onMessage($clientId, $message)
    {
        if($message == 'heart-beat')
        {
            LibGateway::sendToClient($clientId, '{"type":"pong","message":""}');
            return '';
        }

        $messageData = json_decode($message, true);
        if(!$messageData || !isset($messageData['canvas_id'])) return '';

        global $config, $app;

        LibGateway::$registerAddress = $config->board->gateway->registerAddress;
        // if request client id not in client list,close it.

        $clientList = LibGateway::getClientIdListByGroup($messageData['canvas_id']);
        if(!in_array($clientId, $clientList))
        {
            LibGateway::closeClient($clientId);
            return '';
        }
        if(isset($messageData['ids'])&& $messageData['ids'] == 0) return '';

        $messageData['server_resp'] = true;
        //lastOptionId
        if(isset($messageData['data']['lastOptionId'])) $messageData['data']['lastOptionId'] = $messageData['option_id'];

        if($messageData['type'] !== 'batch') LibGateway::sendToGroup($messageData['canvas_id'], json_encode($messageData));

        $app->session->set('canvas_id', $messageData['canvas_id']);
        $app->session->set('uid', isset($messageData['option_id']) ? $messageData['option_id'] : '');

        switch ($messageData['type']) {
            case 'add':
                self::saveOption($messageData, true);
                break;
            case 'option':
                self::saveOption($messageData);
                break;
            case 'remove':
                self::remove($messageData);
                break;
            case 'delete':
            case 'batch':
                self::batch($messageData);
                break;
            case 'action':
                $app->session->set('addSeconds'.$messageData['canvas_id'], $messageData['addSeconds']);
                $app->session->set('pause'.$messageData['canvas_id'], $messageData['pause']);
                break;
            default:
                break;
        }
        echo "onMessage 「{$clientId}」\r\n";
    }

    public static function onClose($clientId)
    {
        if(!empty($_SESSION['canvas_id']))
        {
            global $config, $app;
            LibGateway::$registerAddress = $config->board->gateway->registerAddress;

            $boardModelFile = $app->setModelFile('board');
            helper::import($boardModelFile);
            $boardModel = new boardModel();

            $canvas_id = (int)$_SESSION['canvas_id'];
            $list      = array_values($boardModel->getCanvasMember($canvas_id));
            $online    = LibGateway::getUidListByGroup($canvas_id);
            $online    = array_values($online);
            $type      = 'online';
            $message = compact('canvas_id', 'online', 'type', 'list');
            LibGateway::sendToGroup($canvas_id, json_encode($message));
        }
        echo "onClose「{$clientId}」\r\n";
    }

    private static function saveOption($messageData, $add = false)
    {
        //option 批量处理
        if(!isset($messageData['sub_id']))
        {
            foreach((array)$messageData['data'] as $layer) self::updateOrCreateLayerByOption($layer, $messageData['option_id']);
        }
        else
        {
            self::updateOrCreateLayerByOption($messageData['data'], $messageData['option_id']);
        }
    }

    /**
     * update or create option layer
     */
    public static function updateOrCreateLayerByOption($data, $optionId)
    {
        global $db;
        $findData = array(
            'canvas' => $data['canvasId'],
            'subID'  => $data['id']
        );
        $saveData['sort'] = $data['sort'] ?? 1;
        $layer = $db->select('id, type, subID, data')->from(str_replace('`', '', TABLE_BOARD_LAYER))->where('subID= :subID')->bindValues(array('subID' => $data['id']))->row();
        if($layer)
        {
            if($layer['type'] == 'block' && isset($data['used']) && empty($data['used'])) $saveData['cards'] = array();
            //增加增量更新
            $saveData['data'] = !empty($layer['data']) ? json_decode($layer['data'], true) : array();
            foreach(array_keys($data) as $dataName) $saveData['data'][$dataName] = $data[$dataName];
            //v3版本以scale缩放，历史数据在v3上操作后以scale保存，去掉matrix属性
            if(isset($data['scale']) && isset($saveData['data']['matrix'])) unset($saveData['data']['matrix']);

            $saveData['data']       = json_encode($saveData['data']);
            $saveData['editedDate'] = helper::now();
            $db->update(str_replace('`', '', TABLE_BOARD_LAYER))->cols($saveData)->where("id={$layer['id']}")->query();
        }
        else
        {
            $saveData['createdBy']   = $data['lastOptionId'] ?? $optionId;
            $saveData['data']        = json_encode($data);
            $saveData['type']        = $data['type'] ?? 'note';
            $saveData['createdDate'] = helper::now();
            $save = array_merge($findData, $saveData);

            if($saveData['type'] == 'object' && isset($data['objectType']))
            {
                global $app;
                $boardModelFile = $app->setModelFile('board');
                helper::import($boardModelFile);
                $boardModel = new boardModel();
                $type       = ucfirst($data['objectType']);

                $boardModel->createImportAction($findData['canvas'], "import{$type}", '', $data['data']['id'], $data['editedBy']);
            }

            $db->insert(str_replace('`', '', TABLE_BOARD_LAYER))->cols($save)->query();
        }
    }

    private static function remove($messageData)
    {
        global $db;
        $db->delete(str_replace('`', '', TABLE_BOARD_LAYER))->where('subID= :subID')->bindValues(array('subID' => $messageData['sub_id']))->query();
    }

    private static function batch($messageData)
    {
        if(!isset($messageData['option_id'])) return;

        global $db, $config;

        if($messageData['type'] == 'delete')
        {
            $ids = $messageData['ids'] ?? array($messageData['sub_id']);
            $idsWithQuotes = array_map(function($id) {
                return "'" . addslashes($id) . "'";
            }, $ids);
            $idsString = implode(',', $idsWithQuotes);
            $db->delete(str_replace('`', '', TABLE_BOARD_LAYER))->where("subID in ($idsString)")->query();
        }

        //batch move
        if($messageData['type'] == 'batch')
        {
            if(!isset($messageData['ids'])) return;
            $batchIds = array();
            //format x,y
            $moveX = $messageData['data']['x'] ?? 0;
            $moveY = $messageData['data']['y'] ?? 0;

            foreach($messageData['ids'] as $subId)
            {
                $layer = $db->select('*')->from(str_replace('`', '', TABLE_BOARD_LAYER))->where('subID= :subID')->bindValues(array('subID' => $subId))->row();
                if(!$layer) continue;
                $batchIds[] = $subId;
                $layerData  = !empty($layer['data']) ? json_decode($layer['data'], true) : array();
                $matrixData = $layerData['matrix'] ?? array(1, 0, 0, 1, 0, 0);

                $layerData['x'] = (float)($layerData['x'] + $moveX/$matrixData[0]);
                $layerData['y'] = (float)($layerData['y'] + $moveY/$matrixData[3]);
                //lastOptionId
                $layerData['lastOptionId'] = $messageData['option_id'];
                //批量处理颜色、字符大小和签名
                if($layerData['type'] == 'note')
                {
                    foreach(array('color','textSize','textColor','link','shape','width','height', 'isHide') as $attr)
                    {
                        if(isset($messageData['data'][$attr])) $layerData[$attr] = $messageData['data'][$attr];
                    }
                }
                //2023-1213增加了link的isHide属性
                if(in_array($layerData['type'], array('link','image')))
                {
                    foreach(['isHide'] as $attr)
                    {
                        if(isset($messageData['data'][$attr])) $layerData[$attr] = $messageData['data'][$attr];
                    }
                }
                //批量处理区块属性
                if($layerData['type'] == 'block')
                {
                    $blocks = array(
                        'highlight',
                        'elements',
                        'groupMx',
                        'groupMy',
                        'isShowTitle',
                        'isShowBlock',
                        'fillColor',
                        'strokeColor',
                        'strokeType',
                        'strokeThickness',
                        'opacity',
                        'blockTitle',
                        'textColor'
                    );
                    foreach($blocks as $attr)
                    {
                        if(isset($messageData['data'][$attr])) $layerData[$attr] = $messageData['data'][$attr];
                    }
                }
                //批量处理对象卡片属性
                if($layerData['type'] == 'object')
                {
                    $blocks = array('color', 'textColor');
                    foreach($blocks as $attr)
                    {
                        if(isset($messageData['data'][$attr])) $layerData[$attr] = $messageData['data'][$attr];
                    }
                }
                $layerData['isSign'] = $messageData['data']['isSign'] ?? ($layerData['isSign'] ?? false);
                //resize 计算
                if(isset($messageData['data']['matrix']))
                {
                    $matrix = $messageData['data']['matrix'];
                    $layerData['matrix'] = array(
                        $matrixData[0]*$matrix[0],
                        0,
                        0,
                        $matrixData[3]*$matrix[3],
                        $matrixData[4]*$matrix[0] + $matrix[4],
                        $matrixData[5]*$matrix[3] + $matrix[5],
                    );
                }
                if(array_key_exists('group', $messageData['data']) && is_null($messageData['data']['group']))
                {
                    //解组删除组信息
                    $db->delete(str_replace('`', '', TABLE_BOARD_LAYER))->where('subID= :subID')->bindValues(array('subID' => $layerData['group']['id']))->query();
                    $layerData['group'] = null;
                }
                if(isset($messageData['data']['group'])) $layerData['group'] = $messageData['data']['group'];
                if(isset($messageData['data']['elements'])) $layerData['elements'] = $messageData['data']['elements'];

                $db->update(str_replace('`', '', TABLE_BOARD_LAYER))->cols(array('data' => json_encode($layerData), 'editedDate' => helper::now()))->where('subID= :subID')->bindValues(array('subID' => $subId))->query();
            }

            //操作过的ids执行广播
            $messageData['ids'] = $batchIds;
            LibGateway::$registerAddress = $config->board->gateway->registerAddress;
            LibGateway::sendToGroup($messageData['canvas_id'], json_encode($messageData));
        }
    }
}
