/**
 * Toggle acl.
 *
 * @param  string $acl
 * @param  string $type
 * @access public
 * @return void
 */
function toggleAcl(type)
{
    const acl = $('input[name=acl]:checked').val();

    if(acl == 'private')
    {
        $('#whiteListBox').removeClass('hidden');
        $('#groupBox').removeClass('hidden');
    }
    else
    {
        $('#whiteListBox').addClass('hidden');
        $('#groupBox').addClass('hidden');
    }
}

/**
 * The team or whitelist member that loads space.
 *
 * @oaram  int    spaceID
 * @access public
 * @return void
 */
function loadUsers(spaceID)
{
    var field = spaceType == 'private' ? 'whitelist' : 'team';
    var link  = createLink('board', 'ajaxLoadUsers', 'spaceID='+ spaceID + '&field=' + field + '&selectedUser=' + $('#' + field).val());
    $.get(link, function(data)
    {
        $('#' + field).replaceWith(data);
        $('#' + field).next('.picker').remove();
        $('#' + field).picker();
    });

    if(spaceType != 'private') loadOwners(spaceID);
}

/**
 * The owners that loads space.
 *
 * @oaram  int    spaceID
 * @access public
 * @return void
 */
function loadOwners(spaceID)
{
    var link = createLink('board', 'ajaxLoadUsers', 'spaceID='+ spaceID + '&field=owner&selectedUser=' + $('#owner').val());

    $.get(link, function(data)
    {
        $('#owner').replaceWith(data);
        $('#owner' + "_chosen").remove();
        $('#owner').next('.picker').remove();
        $('#owner').chosen();
    });
}

window.loadAllUsers = function()
{
    const link = $.createLink('board', 'ajaxLoadUsers', 'spaceID=0&field=owner&type=all');
    $.getJSON(link, function(data)
    {
        $('[name=owner]').zui('picker').render({items: data});
    });
}

window.locate2Board = function(link, tip = '')
{
    if(tip !== '') $('#whiteListBox .check-list').append(tip);

    setTimeout(zui.Modal.hide(), 1500);
    setTimeout(function(){openPage(link);}, 2000);
}

function checkUser()
{
    const acl = $('input[name=acl]:checked').val();
    if (acl === 'open') return true;
    const picker = $('#whiteUsers').zui('picker');
    const users   = picker ? picker.$.value : '';
    const spaceID = $('input[name=space]').val();

    var link = $.createLink('board', 'ajaxCheckUsers', 'spaceID='+ spaceID);
    var data = {users: users};

    $.post(link, data, function(response)
    {
        var data = JSON.parse(response);
        $('#addWhitelistTip').remove();
        if(data.result === 'fail')
        {
            $('#whiteListBox .check-list').append(data.message);
        }
    }, 'json')
    return false;
}

window.toggleBoardCollector = function(canvasID)
{
    const hintLang = $('.card-list').data('hintLang');
    const url      = $.createLink('board', 'ajaxCollect', `canvasID=${canvasID}`);
    $.ajaxSubmit(
    {
        url: url,
        onSuccess: function(result)
        {
            $('#main').find(`.board-canvas[data-id="${canvasID}"]`).toggleClass('is-collector', !!result.data.isCollector);
            $('#main').find(`.board-canvas[data-id="${canvasID}"] .board-collector-star`).prop({title: !!result.data.isCollector ? hintLang.cancelCollect : hintLang.collect});
        }
    });
};

window.tryLoadMain = function()
{
    if($('#mainContentCell').length) loadCurrentPage('#mainContentCell,#featureBar');
};

window.handleDeleteBoard = function()
{
    if(window.zboard) return window.zboard.cmd.executeCommand('canvas.quit');
    tryLoadMain();
};

window.handleEditBoard = function(id, name)
{
    if(window.zboard)
    {
        window.zboard.BoardEditor.getBoard().canvas.data.value.name = name;
        return;
    }
};

window.handleActivateBoard = function()
{
    if(window.zboard)
    {
        window.location.reload();
        return;
    }
    tryLoadMain();
};

window.deleteBoard = function(canvasID, options)
{
    if(options && options.confirm)
    {
        zui.Modal.confirm({message: options.confirm, icon: 'icon-exclamation-sign', iconClass: 'warning-pale rounded-full icon-2x'}).then(res =>
        {
            if(res) deleteBoard(canvasID, $.extend({}, options, {confirm: false}));
        });
        return;
    }
    $.ajaxSubmit(
    {
        url: $.createLink('board', 'delete', `canvasID=${canvasID}`),
        onSuccess: handleDeleteBoard
    });
};

window.deleteSpace = function(spaceID, options)
{
    if(options && options.confirm)
    {
        zui.Modal.confirm({message: options.confirm, icon: 'icon-exclamation-sign', iconClass: 'warning-pale rounded-full icon-2x'}).then(res =>
        {
            if(res) deleteSpace(spaceID, $.extend({}, options, {confirm: false}));
        });
        return;
    }
    $.ajaxSubmit(
    {
        url: $.createLink('board', 'deleteSpace', `spaceID=${spaceID}`)
    });
};

window.changeSpaceType = function()
{
    const type = $('[name=type]:checked').val();
}

window.initCardList = function()
{
    const hintLang = $('.card-list').data('hintLang');
    $('.card-list-item .board-canvas').each(function()
    {
        $(this).find('.board-collector-star').prop({title: $(this).hasClass('is-collector') ? hintLang.cancelCollect : hintLang.collect});
    });
}
