<?php
/**
 * The board canvas file of board module of ZenTaoPMS.
 * @copyright   Copyright 2009-2024 禅道软件（青岛）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.zentao.net)
 * @license     ZPL(https://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Hao Sun<sunhao@easycorp.ltd>
 * @package     board
 * @link        https://www.zentao.net
 */
namespace zin;

set::zui();

$isIpdOrVision = $config->edition == 'ipd' && $config->vision == 'or';
$storyType     = $isIpdOrVision ? 'demand' : 'story';
if($config->vision == 'lite') $storyType = 'projectstory';
$actions       = array();
jsVar('gradeGroup', $gradeGroup);

if($this->board->isClickable($canvas, 'editBoard'))                         $actions['editBoard'] = array('label' => $lang->edit, 'iconClass' => 'icon icon-pencil mr-1', 'tagName' => 'a', 'href' => createLink('board', 'editboard', "canvasID={$canvas->id}"), 'data-toggle' => 'modal');
if($this->board->isClickable($canvas, 'close'))                             $actions['close']    = array('label' => $lang->close, 'iconClass' => 'icon icon-off mr-1', 'tagName' => 'a', 'href' => createLink('board', 'close', "canvasID={$canvas->id}"), 'data-toggle' => 'modal');
if($this->board->isClickable($canvas, 'activate') && $canvas->deleted != 1) $actions['activate'] = array('label' => $lang->activate, 'iconClass' => 'icon icon-magic mr-1', 'tagName' => 'a', 'href' => createLink('board', 'activate', "canvasID={$canvas->id}"), 'data-toggle' => 'modal');
if($this->board->isClickable($canvas, 'delete'))                            $actions['delete']   = array('label' => $lang->delete, 'iconClass' => 'icon icon-trash mr-1', 'data-on' => 'click', 'data-call' => "deleteBoard($canvas->id, options)", 'data-confirm' => $lang->board->confirmDelete);

$historyAction     = array('label' => $lang->history, 'type' => 'history-toggle', 'iconClass' => 'icon icon-history mr-1', 'data-on' => 'click', 'data-do' => 'toggleBoardHistory()');
$updateLayerAction = array('label' => $lang->board->updateLayer, 'class' => 'ajax-submit flex items-center gap-1 p-2 rounded hover:bg-primary-500 hover:text-white !justify-start', 'iconClass' => 'icon icon-refresh mr-1', 'tagName' => 'a', 'href' => createLink('board', 'ajaxUpdateLayer', "canvasID=$canvasID"), 'data-method' => 'get');

if(empty($actions))
{
    if($canvas->status != 'closed') $actions[] = $updateLayerAction;
    $actions[] = $historyAction;
}
else
{
    $prependActions = array($historyAction, array('type' => 'divider'));
    if($canvas->status != 'closed') array_unshift($prependActions, $updateLayerAction);
    $actions = array_merge($prependActions, $actions);
}

$importActions = array();
if(hasPriv($storyType, 'view') && $canvas->status != 'closed' && $canvas->deleted == 0)
{
    $importActions[] = array('label' => $lang->board->story, 'objectType' => 'story', 'iconClass' => 'icon icon-product');
}
$editorConfig = array('board' => array());
$editorConfig['board']['importActions']       = $importActions;
$editorConfig['board']['objectMap']           = array();
$editorConfig['board']['objectMap']['story']  = array('cursorImage' => array('class' => 'icon icon-product icon-2x'));
$editorConfig['board']['onImportObjects']     = jsRaw('window.openImportModal');
$editorConfig['board']['onRenderObject']      = jsRaw('window.onRenderObject');
$editorConfig['board']['onConvertObject']     = jsRaw('window.onConvertObject');
$editorConfig['board']['onRenderConvertInfo'] = jsRaw('window.onRenderConvertInfo');

$storyStatusList = $lang->story->statusList;
if($isIpdOrVision) $storyStatusList = array_merge($storyStatusList, $lang->demand->statusList);
jsVar('storyStatusList', $storyStatusList);
jsVar('langEstimate', $lang->board->estimate);
jsVar('langChildrenAB', $lang->story->childrenAB);
jsVar('usersAvatar', $usersAvatar);
jsVar('hourUnit', $config->hourUnit);
jsVar('deleted', $lang->deleted);
jsVar('storyType', $storyType);
jsVar('canvasID', $canvasID);
jsVar('storyTypeList', $lang->board->storyTypeList);

$priList = array();
foreach($lang->story->priList as $key => $pri)
{
    if(!empty($pri)) $priList[] = array(
        'innerClass' => 'item-pri',
        'titleClass' => 'item-pri-title pri-' . $key,
        'text'       => $pri,
        'data-pri'   => $key,
    );
}

boardEditor
(
    set::canvasID($canvasID),
    set::canvas($canvas),
    set::actions($actions),
    set::config($editorConfig)
);

div
(
    setData(array('priList' => $priList, 'canEditStory' => common::hasPriv('story', 'edit'), 'canvasID' => $canvasID, 'isIpdOrVision' => $isIpdOrVision)),
    setID('boardHistory'),
    setClass('absolute right-0 top-10 bottom-0 z-100 transition-transform duration-300 pt-0.5'),
    history
    (
        setClass('h-full rounded-l ring shadow-lg canvas'),
        set::objectID((int)$canvasID)
    ),
    btn
    (
        setClass('square absolute right-3 top-2 z-1'),
        span(setClass('close')),
        bind::click('toggleBoardHistory()'),
        set::type('ghost')
    )
);

render('pageBase');
