<?php
/**
 * The ui file of board of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2024 禅道软件（青岛）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.zentao.net)
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Fei Lu<lufei@easycorp.ltd>
 * @package     board
 * @link        https://www.zentao.net
 */

namespace zin;

modalHeader(set::title($lang->board->createTeamBoard), set::titleClass('text-lg font-bold'));

formPanel
(
    $app->getClientLang() === 'en' ? set::labelWidth('120px') : null,
    formRow
    (
        formGroup
        (
            set::label($lang->board->affiliatedSpace),
            set::required(true),
            picker
            (
                set::name('space'),
                set::items($spaces),
                set::value($spaceID),
                on::change("checkUser")
            )
        )
    ),
    formRow
    (
        formGroup
        (
            set::label($lang->board->boardName),
            set::required(true),
            set::name('name')
        )
    ),
    formRow
    (
        on::click('#allUsers', 'loadAllUsers'),
        set::className('ownerBox'),
        formGroup
        (
            set::label($lang->board->owner),
            set::required(true),
            inputGroup
            (
                picker
                (
                    set::name('owner'),
                    set::items($users),
                    set::value($this->app->user->account)
                ),
                span
                (
                    setClass('input-group-addon'),
                    a
                    (
                        setID('allUsers'),
                        set('href', 'javascript:;'),
                        $lang->board->allUsers
                    )
                )
            )
        )
    ),
    formRow
    (
        set::className('collaboratorBox'),
        formGroup
        (
            set::label($lang->board->collaborator),
            picker
            (
                set::name('collaborator'),
                set::multiple(true),
                set::items($users)
            ),
            icon
            (
                'help',
                set('data-toggle', 'tooltip'),
                set('data-title', $lang->board->collaboratorTip),
                set('data-placement', 'left'),
                set('data-type', 'white'),
                set('data-class-name', 'text-gray border border-light w-60'),
                setClass('text-gray collaboratorTip')
            )

        )
    ),
    formRow
    (
        setID('aclBox'),
        formGroup
        (
            set::label($lang->board->acl),
            radioList
            (
                set::name('acl'),
                set::items($lang->board->aclList),
                set::value($acl),
                on::change("toggleAcl('board')")
            )
        )
    ),
    formRow
    (
        setID('whiteListBox'),
        setClass('hidden'),
        formGroup
        (
            set::label($lang->board->whiteList),
            div
            (
                setClass('w-full check-list'),
                div
                (
                    setClass('w-full'),
                    inputGroup
                    (
                        $lang->board->group,
                        picker
                        (
                            set::name('groups[]'),
                            set::items($groups),
                            set::multiple(true)
                        )
                    )
                ),
                div
                (
                    setClass('w-full'),
                    userPicker(
                        setID('whiteUsers'),
                        set::label($lang->board->user),
                        set::items($users),
                        on::change("checkUser")
                    )
                )
            )
        )
    ),
    formRow
    (
        setID('aclAPIBox'),
        setClass('hidden'),
        formGroup
        (
            set::label($lang->board->acl),
            radioList
            (
                set::name('acl'),
                set::items($lang->api->aclList)
            )
        )
    ),
    formRow
    (
        setID('aclOtherBox'),
        setClass('hidden'),
        formGroup
        (
            set::label($lang->board->acl),
            radioList
            (
                set::name('acl'),
                set::items($lang->board->aclList)
            )
        ),
        formHidden('type', $type)
    )
);

render();
