<?php
/**
 * The import story view file of board module of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2024 禅道软件（青岛）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.zentao.net)
 * @license     ZPL(https://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Fei Lu<lufei@easycorp.ltd>
 * @package     board
 * @link        https://www.zentao.net
 */

namespace zin;

$isInModal           = isInModal();
$isLite              = $config->vision == 'lite';

if($isInModal) set::size('lg');

jsVar('childrenAB', $lang->story->childrenAB);
jsVar('gradeGroup', !empty($gradeGroup) ? $gradeGroup : array());

modalHeader(set::title($lang->board->importStory), set::titleClass('text-lg font-bold'));
$productList = !isset($pools) ? $products : $pools;
div
(
    setID('importObjectSearch'),
    setClass('canvas rounded ring mb-2 pr-2'),
    setData('actionUrl', $actionUrl),
    setData('changeUrl', $changeUrl),
    setData('objectType', $storyType), // 设置导入类型。
    div
    (
        setClass('form-horz pt-4 pr-2'),
        formRow
        (
            formGroup
            (
                setClass('w-1/2 flex-none ' . ($isLite ? 'hidden' : '')),
                set::label($lang->board->storyType),
                set::required(true),
                picker
                (
                    set::name('storyType'),
                    set::items($this->lang->board->storyTypeList),
                    set::value($storyType),
                    set::required(true),
                    set::onChange(jsRaw('handleChangeImportType'))
                )
            ),
            formGroup
            (
                setClass('flex-auto'),
                set::label($lang->board->product),
                set::required(true),
                picker
                (
                    set::name('productID'),
                    set::items($productList),
                    set::required(true),
                    set::value(!empty($productList) ? $productID : '')
                )
            )
        )
    ),
    searchForm
    (
        set::_options(array('class' => 'pb-0')),
        set::innerClass('shadow-none ring-0'),
        set::module($searchModule),
        set::simple(true),
        set::show(true),
        set::noMore(),
        set::beforeSearch(jsRaw('handleImportBeforeSearch')),
        set::onSearch(jsRaw('handleImportObjectSearch'))
    )
);

$cols = $config->board->importStory->dtable->fieldList;
if(isset($cols['product']) && !empty($products)) $cols['product']['map'] = $products;
if(isset($cols['pool']) && !empty($pools)) $cols['pool']['map'] = $pools;
if(isset($cols['module']) && !empty($modules)) $cols['module']['map'] = $modules;

if($storyType == 'requirement')
{
    $cols['title']['title'] = str_replace($lang->SRCommon, $lang->URCommon, $lang->story->title);
    unset($cols['planTitle']);
    unset($cols['stage']);
}

if($config->vision != 'lite' && $storyType == 'story')
{
    unset($cols['reviewer'], $cols['status']);
}

$footToolbar['items'][] = array(
    'text'      => $lang->board->import,
    'className' => 'btn secondary batch-btn ajax-btn import-story-btn size-sm',
    'onClick'   => jsRaw('handleImportObject')
);

dtable(set::groupDivider(true), set::cols($cols), set::userMap($users), set::data($stories), set::orderBy($orderBy), set::checkable(true), set::extraHeight(222), set::showToolbarOnChecked(true), set::sortLink(createLink('board', 'importStory', "boardID={$boardID}&storyType={$storyType}&productID={$productID}&browseType={$browseType}&queryID={$queryID}&orderBy={name}_{sortType}")), set::checkable(true), set::footToolbar($footToolbar), set::footPager(usePager()), set::onRenderCell(!empty($gradeGroup) ? jsRaw('window.renderStoryCell'): null));
