<?php
/**
 * The left tree view file of board module of ZenTaoPMS.
 * @copyright   Copyright 2009-2024 禅道软件（青岛）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.zentao.net)
 * @license     ZPL(https://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Fei Lu<lufei@easycorp.ltd>
 * @package     board
 * @link        https://www.zentao.net
 */
namespace zin;

$moduleName = $this->app->rawModule;
$methodName = $this->app->rawMethod;

$treeProps = array();
$treeProps['items'] = array_map(function($id, $text) use($methodName, $browseType, $objectID, $orderBy, $libID)
{
    $space     = $this->board->getSpaceById($id);
    $canEdit   = $this->board->isClickable($space, 'editSpace');
    $canDelete = $this->board->isClickable($space, 'deleteSpace');
    $result = array
    (
        'key'        => $id,
        'hint'       => $text,
        'text'       => $text,
        'icon'       => 'board-lib',
        'selected'   => $libID == $id && $browseType != 'bySearch',
        'titleClass' => 'clip',
        'url'        => createLink('board', $methodName, "objectID={$objectID}&libID={$id}&browseType={$browseType}&orderBy={$orderBy}"),
        '_data'      => array('id' => $id, 'editDisabled' => !$canEdit, 'deleteDisabled' => !$canDelete)
    );

    if(!$canEdit && !$canDelete) $result['actions'] = false;

    return $result;
}, array_keys($libTree), array_values($libTree));

$treeDropdown = array('placement' => 'bottom-end', 'items' => array());
$treeDropdown['items'][] = array('key' => 'edit', 'text' => $lang->edit, 'data-toggle' => 'modal', 'url' => createLink('board', 'editSpace', 'spaceID={id}')); // Define space edit trigger, use {id} to represent the id of the current lib id.
$treeDropdown['items'][] = array('key' => 'delete', 'text' => $lang->delete, 'data-on' => 'click', 'data-call' => "deleteSpace({id}, options)", 'data-confirm' => $lang->board->confirmDeleteSpace);
$treeDropdown['menu'] = array('getItem' => jsRaw(<<<JS
function(item)
{
    const libInfo = this.props.relativeTarget.target._data;
    item.disabled = libInfo[item.key + 'Disabled'];
    if(item.disabled) return '';
    if(item.url) item.url = zui.formatString(item.url, libInfo);
    if(item['data-call']) item['data-call'] = zui.formatString(item['data-call'], libInfo);
    if(item['data-call'] && item.disabled) item['data-call'] = '';
    return item;
}
JS
)); // Define js callback to format item url, this.props.relativeTarget.target is the target item defined in tree.
$treeProps['itemActions'] = array();
$treeProps['itemActions'][] = array('type' => 'dropdown', 'icon' => 'ellipsis-v', 'caret' => false, 'hint' => $lang->more, 'dropdown' => $treeDropdown);

$spaceName = isset($libTree[$libID]) ? $libTree[$libID] : $lang->board->allSpace;
$closeBtn = isset($libTree[$libID]) ? btn
(
    setClass('btn-close rounded-full'),
    set::icon('close'),
    set::url(createLink('board', $methodName, "objectID={$objectID}&libID=0&browseType={$browseType}&orderBy={$orderBy}")),
    set::size('sm'),
    set::type('ghost')
) : null;

h::js("$('#mainContainer').addClass('has-module-menu-header')");

sidebar
(
    div(
        h::header
        (
            setClass('module-menu-header h-10 flex items-center pl-4 flex-none gap-3 is-fixed rounded rounded-r-none canvas'),
            span
            (
                set::title($spaceName),
                setClass('module-title text-lg font-semibold clip'),
                $spaceName
            ),
            $closeBtn
        )
    ),
    !empty($treeProps['items']) ? div(setID('boardMenu'), setClass('shadow rounded bg-canvas col py-2'), setCssVar('--menu-selected-bg', 'none'), zui::tree
    (
        set::_tag('menu'),
        set::_class('tree col flex-auto scrollbar-hover scrollbar-thin overflow-y-auto overflow-x-hidden pl-4 pr-1'),
        set::defaultNestedShow(true),
        set::hover(true),
        set($treeProps)
    )) : null,
    h::css(".icon-board-lib {height: 14px; width: 14px !important; background-image: url(\"data:image/svg+xml,%3C%3Fxml version='1.0' encoding='UTF-8'%3F%3E%3Csvg viewBox='0 0 14 14' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='m13.649 3.3682h-13.65l2.5339-3.3682 8.5761 9.4134e-7 2.5396 3.3682z' fill='%23D0F6E8'/%3E%3Cpath d='m9.7656e-4 3.3701h13.65v8.2808c0 1.1046-0.8954 2-2 2h-9.6495c-1.1046 0-2-0.8954-2-2v-8.2808z' fill='%237ADFBA'/%3E%3Crect x='6.3252' y='.5791' width='1' height='2.0016' rx='.5' fill='%23fff'/%3E%3Cpath d='m5 10.834v-5h1.7786c1.1034 0 1.9456 0.2973 1.9456 1.2297 0 0.45946-0.27586 0.93244-0.73321 1.0811v0.03378c0.58076 0.12838 1.0091 0.50676 1.0091 1.1824 0 1.0068-0.90018 1.473-2.0835 1.473h-1.9165zm1.0744-2.9662h0.62432c0.6824 0 0.98004-0.25676 0.98004-0.65541 0-0.43919-0.31942-0.61486-0.96552-0.61486h-0.63884v1.2703zm0 2.1959h0.74773c0.73321 0 1.1325-0.24323 1.1325-0.7635 0-0.48649-0.39202-0.68919-1.1325-0.68919h-0.74773v1.4527z' fill='%23fff'/%3E%3C/svg%3E%0A\");}")
);
