<?php
/**
 * The tableContents view file of board module of ZenTaoPMS.
 * @copyright   Copyright 2009-2024 禅道软件（青岛）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.zentao.net)
 * @license     ZPL(https://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Fei Lu<lufei@easycorp.ltd>
 * @package     board
 * @link        https://www.zentao.net
 */
namespace zin;

$canCreateBoard    = common::hasPriv('board', 'createBoard');
$canCreateSpace    = common::hasPriv('board', 'createSpace');
$canCollectBoard   = common::hasPriv('board', 'collect');
$canViewBoard      = common::hasPriv('board', 'creation');
$createSpaceButton = $canCreateSpace ? item(set::icon('plus'), set::text($this->lang->board->createSpace), set::className('secondary'), set::url(createLink('board', 'createSpace', "type={$type}")), set('data-toggle', 'modal')) : null;
$createBoardButton = $canCreateBoard ? item(set::icon('plus'), set::text($this->lang->board->createBoard), set::className('primary'), set::url(createLink('board', 'createBoard', "type={$type}&spaceID={$libID}")), set('data-toggle', 'modal')) : null;
if(!$canCollectBoard) unset($lang->board->featureBar['teamboard']['collectBy']);

if(empty($libTree))
{
    toolbar(item(set::icon('plus'), set::text($this->lang->board->createSpace), set::className('primary'), set::url(createLink('board', 'createSpace', "type={$type}")), set('data-toggle', 'modal')));

    unset($lang->board->featureBar["{$type}board"]);
    featureBar();

    div
    (
        setClass('dtable-empty-tip rounded shadow canvas'),
        div
        (
            setClass('row gap-4 items-center'),
            div(setClass('text-gray'), $lang->board->error->noSpaceData),
            $canCreateSpace ? btn
            (
                set::icon('plus'),
                set::text($lang->board->createSpace),
                set::className('primary-pale border-primary'),
                set::url(createLink('board', 'createSpace', "type={$type}")),
                toggle::modal()
            ) : null
        )
    );
    return;
}

include 'lefttree.html.php';

featureBar
(
    set::current($browseType),
    set::link(createLink('board', $this->app->rawMethod, "objectID={$objectID}&libID={$libID}&browseType={key}&orderBy={$orderBy}")),
    li(searchToggle(set::module("{$type}Board"), set::open($browseType == 'bySearch')))
);

toolbar($createSpaceButton, $createBoardButton);

if(empty($canvases))
{
    div
    (
        setClass('dtable-empty-tip rounded shadow canvas'),
        div
        (
            setClass('row gap-4 items-center'),
            div(setClass('text-gray'), $lang->error->noData),
            $canCreateBoard ? btn
            (
                set::icon('plus'),
                set::text($lang->board->createBoard),
                set::className('primary'),
                set::url(createLink('board', 'createBoard', "type={$type}&spaceID={$libID}")),
                toggle::modal()
            ) : null
        )
    );
}
else
{
    $cards = array();
    foreach($canvases as $canvas)
    {
        $actions = array(); // Actions for the dropdown menu.
        if($this->board->isClickable($canvas, 'editBoard')) $actions[] = array('text' => $lang->edit, 'url' => createLink('board', 'editboard', "canvasID={$canvas->id}"), 'data-toggle' => 'modal');
        if($this->board->isClickable($canvas, 'close')) $actions[] = array('text' => $lang->close, 'url' => createLink('board', 'close', "canvasID={$canvas->id}"), 'data-toggle' => 'modal');
        if($this->board->isClickable($canvas, 'activate')) $actions[] = array('text' => $lang->activate, 'url' => createLink('board', 'activate', "canvasID={$canvas->id}"), 'data-toggle' => 'modal');
        if($this->board->isClickable($canvas, 'delete')) $actions[] = array('text' => $lang->delete, 'data-on' => 'click', 'data-call' => "deleteBoard($canvas->id, options)", 'data-confirm' => $lang->board->confirmDelete);
        $closed = $canvas->status == 'closed';

        $cards[] = div
        (
            setClass('card-list-item item'),
            div
            (
                set::title($canViewBoard ? $canvas->name : $lang->board->error->noPrivViewBoard),
                setClass('card ring pt-2 pb-1 cursor-pointer group board-canvas' . ($canViewBoard ? ' open-url ' : ''), $canvas->isCollector ? 'is-collector' : ''),
                setData('url', createLink('board', 'view', "canvasID={$canvas->id}")),
                setData('id', $canvas->id),
                div
                (
                    setClass('card-img'),
                    $canvas->cover ? img(setClass('w-full h-full object-cover'), set::src($canvas->cover)) : null
                ),
                div(setClass('card-heading pt-2 pb-0 relative'), div
                (
                    setClass('card-title font-bold group-hover:text-primary text-clip overflow-hidden whitespace-nowrap flex-auto'),
                    set::title($canvas->name),
                    $canvas->name
                ), $closed ? label(setClass('gray-600-pale'), set::size('sm'), $lang->board->statusList['closed']) : null, $canCollectBoard ? btn
                (
                    setClass('flex-none not-open-url board-collector-star'),
                    set::icon('star-empty'),
                    set::size('sm'),
                    set::type('ghost'),
                    bind::click("toggleBoardCollector($canvas->id)")
                ) : null),
                div
                (
                    setClass('card-footer row justify-between text-gray'),
                    div(zget($users, $canvas->createdBy, $canvas->createdBy)),
                    div($lang->board->createOn, ' ', date(DT_DATETIME2, strtotime($canvas->createdDate)))
                ),
                !empty($actions) ? dropdown
                (
                    btn
                    (
                        setClass('absolute top-3 right-3 opacity-0 group-hover:opacity-100'),
                        set::type('ghost'),
                        set::hint($lang->more),
                        set::icon('ellipsis-v'),
                        set::size('sm')
                    ),
                    set::caret(false),
                    set::placement('bottom-end'),
                    set::trigger('hover'),
                    set::items($actions)
                ) : null
            )
        );
    }

    div
    (
        setClass('card-list card-grid bg-white'),
        setCssVar('list-count-per-row', '4'),
        setData(array('hintLang' => $lang->board->hint)),
        h::css('.card-img {height: 134px; margin: 0 8px}'),
        on::init()->call('initCardList'),
        $cards
    );
}

if($pager->recTotal)
{
    pager
    (
        set::_className('py-1 mt-2 justify-end canvas rounded'),
        set::sizeMenuCaret('up'),
        set(usePager())
    );
}
